Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(724)

Unified Diff: content/browser/frame_host/render_frame_host_delegate.h

Issue 2843353003: Move ownership of PowerSaveBlocker from WakeLockServiceContext to WakeLockServiceImpl (Closed)
Patch Set: code rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_delegate.h
diff --git a/content/browser/frame_host/render_frame_host_delegate.h b/content/browser/frame_host/render_frame_host_delegate.h
index 120e18ed8357f4fdc6a55d8a2cd7b884c29404d3..92f6c2b1f1026187cf600b91cef44bd180fa0e5e 100644
--- a/content/browser/frame_host/render_frame_host_delegate.h
+++ b/content/browser/frame_host/render_frame_host_delegate.h
@@ -18,6 +18,7 @@
#include "content/public/browser/site_instance.h"
#include "content/public/common/javascript_dialog_type.h"
#include "content/public/common/media_stream_request.h"
+#include "device/wake_lock/public/interfaces/wake_lock_service.mojom.h"
#include "mojo/public/cpp/bindings/scoped_interface_endpoint_handle.h"
#include "net/http/http_response_headers.h"
#include "ui/base/window_open_disposition.h"
@@ -38,10 +39,6 @@ class Message;
namespace device {
class GeolocationServiceContext;
-
-namespace mojom {
-class WakeLockContext;
-}
}
namespace gfx {
@@ -194,8 +191,8 @@ class CONTENT_EXPORT RenderFrameHostDelegate {
// Gets the GeolocationServiceContext associated with this delegate.
virtual device::GeolocationServiceContext* GetGeolocationServiceContext();
- // Gets the WakeLockServiceContext associated with this delegate.
- virtual device::mojom::WakeLockContext* GetWakeLockServiceContext();
+ // Gets the WakeLockService that serves wake lock requests from the renderer.
+ virtual device::mojom::WakeLockService* GetRendererWakeLock();
// Notification that the frame wants to go into fullscreen mode.
// |origin| represents the origin of the frame that requests fullscreen.
« no previous file with comments | « no previous file | content/browser/frame_host/render_frame_host_delegate.cc » ('j') | device/wake_lock/wake_lock_service_impl.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698